@@ -1,11 +1,10 @@
-context("survtab usage")
+testthat::context("survtab usage")
 
 
 
-test_that("Dates and frac. yrs produce congruent results", {
-  skip_on_cran()
+testthat::test_that("Dates and frac. yrs produce congruent results", {
+  popEpi:::skip_normally()
   library(Epi)
-  library(survival)
   
   x <- data.table(popEpi::sire)
   x <- x[dg_date<ex_date]
@@ -55,12 +54,12 @@ test_that("Dates and frac. yrs produce congruent results", {
                      surv.method = "hazard",
                      breaks = BLd, pophaz = pmd)    
   
-  expect_equal(sty$surv.obs.lo, std$surv.obs.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$surv.obs, std$surv.obs, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$surv.obs.hi, std$surv.obs.hi, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2.lo, std$r.e2.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2, std$r.e2, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2.hi, std$r.e2.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs.lo, std$surv.obs.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs, std$surv.obs, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs.hi, std$surv.obs.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2.lo, std$r.e2.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2, std$r.e2, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2.hi, std$r.e2.hi, scale = 1L, tolerance = 0.0005)
   
   ## pohar perme
   
@@ -74,9 +73,9 @@ test_that("Dates and frac. yrs produce congruent results", {
                      surv.method = "hazard",
                      breaks = BLd, pophaz = pmd)    
   
-  expect_equal(sty$r.pp.lo, std$r.pp.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.pp, std$r.pp, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.pp.hi, std$r.pp.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp.lo, std$r.pp.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp, std$r.pp, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp.hi, std$r.pp.hi, scale = 1L, tolerance = 0.0005)
   
   #### lifetable method
   ## observed survival & Ederer II
@@ -91,12 +90,12 @@ test_that("Dates and frac. yrs produce congruent results", {
                      surv.method = "lifetable",
                      breaks = BLd, pophaz = pmd)    
   
-  expect_equal(sty$surv.obs.lo, std$surv.obs.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$surv.obs, std$surv.obs, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$surv.obs.hi, std$surv.obs.hi, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2.lo, std$r.e2.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2, std$r.e2, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.e2.hi, std$r.e2.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs.lo, std$surv.obs.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs, std$surv.obs, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$surv.obs.hi, std$surv.obs.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2.lo, std$r.e2.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2, std$r.e2, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.e2.hi, std$r.e2.hi, scale = 1L, tolerance = 0.0005)
   
   ## pohar perme
   
@@ -110,18 +109,17 @@ test_that("Dates and frac. yrs produce congruent results", {
                      surv.method = "lifetable",
                      breaks = BLd, pophaz = pmd)    
   
-  expect_equal(sty$r.pp.lo, std$r.pp.lo, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.pp, std$r.pp, scale = 1L, tolerance = 0.0005)
-  expect_equal(sty$r.pp.hi, std$r.pp.hi, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp.lo, std$r.pp.lo, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp, std$r.pp, scale = 1L, tolerance = 0.0005)
+  testthat::expect_equal(sty$r.pp.hi, std$r.pp.hi, scale = 1L, tolerance = 0.0005)
   
 })
 
 
 
-test_that("hazard and lifetable produce congruent results", {
-  skip_on_cran()
+testthat::test_that("hazard and lifetable produce congruent results", {
+  popEpi:::skip_normally()
   library(Epi)
-  library(survival)
   
   x <- data.table(popEpi::sire)
   x <- x[dg_date<ex_date]
@@ -151,13 +149,13 @@ test_that("hazard and lifetable produce congruent results", {
                  pophaz = pmy, breaks = BL,
                  surv.type = "surv.rel", surv.method = "lifetable")
   
-  expect_equal(sth$r.e2, stl$r.e2, scale = 1, tol = 0.0003415)
-  expect_equal(sth$r.e2.lo, stl$r.e2.lo, scale = 1, tol = 0.000354)
-  expect_equal(sth$r.e2.hi, stl$r.e2.hi, scale = 1, tol = 0.00033)
+  testthat::expect_equal(sth$r.e2, stl$r.e2, scale = 1, tol = 0.0003415)
+  testthat::expect_equal(sth$r.e2.lo, stl$r.e2.lo, scale = 1, tol = 0.000354)
+  testthat::expect_equal(sth$r.e2.hi, stl$r.e2.hi, scale = 1, tol = 0.00033)
   
-  expect_equal(sth$surv.obs, stl$surv.obs, scale = 1, tol = 0.00002575)
-  expect_equal(sth$surv.obs.lo, stl$surv.obs.lo, scale = 1, tol = 0.000027)
-  expect_equal(sth$surv.obs.hi, stl$surv.obs.hi, scale = 1, tol = 0.000025)
+  testthat::expect_equal(sth$surv.obs, stl$surv.obs, scale = 1, tol = 0.00002575)
+  testthat::expect_equal(sth$surv.obs.lo, stl$surv.obs.lo, scale = 1, tol = 0.000027)
+  testthat::expect_equal(sth$surv.obs.hi, stl$surv.obs.hi, scale = 1, tol = 0.000025)
   
 })
 
@@ -166,7 +164,6 @@ test_that("hazard and lifetable produce congruent results", {
 ## will not necessarily equal the counts of events.
 # test_that("lifetable counts work with period analysis", {
 #   library(Epi)
-#   library(survival)
 #   x <- Lexis(entry = list(FUT = 0, AGE = dg_age, CAL = get.yrs(dg_date)),
 #              exit = list(CAL = get.yrs(ex_date)),
 #              data = sire[sire$dg_date < sire$ex_date, ],
@@ -197,10 +194,10 @@ test_that("hazard and lifetable produce congruent results", {
 # })
 
 
-test_that("its possible to pass dynamically created arguments", {
-  skip_on_cran()
+testthat::test_that("its possible to pass dynamically created arguments", {
+  popEpi:::skip_normally()
   library(Epi)
-  library(survival)
+  
   x <- Lexis(entry = list(FUT = 0, AGE = dg_age, CAL = get.yrs(dg_date)),
              exit = list(CAL = get.yrs(ex_date)),
              data = sire[sire$dg_date < sire$ex_date, ],
@@ -246,12 +243,12 @@ test_that("its possible to pass dynamically created arguments", {
                     weights = "internal",
                     pyrs = pyrs)
   
-  expect_equal(st1$surv.obs, st2$surv.obs)
+  testthat::expect_equal(st1$surv.obs, st2$surv.obs)
   
 })
 
 
-test_that("getCall & formula methods for survtab work", {
+testthat::test_that("getCall & formula methods for survtab work", {
   data("sire")
   BL <- list(fot=seq(0, 5, by = 1/12),
              per = c("2008-01-01", "2013-01-01"))
@@ -266,8 +263,8 @@ test_that("getCall & formula methods for survtab work", {
   e <- quote(survtab_ag(formula = form, data = x))
   st <- eval(e)
   
-  expect_equal(formula(st), form)
-  expect_equal(getCall(st), e)
+  testthat::expect_equal(formula(st), form)
+  testthat::expect_equal(getCall(st), e)
   
 })
 
@@ -275,7 +272,7 @@ test_that("getCall & formula methods for survtab work", {
 
 
 
-test_that("survtab_ag allows for certain arguments to be length > 1", {
+testthat::test_that("survtab_ag allows for certain arguments to be length > 1", {
   data(sire)
   set.seed(1)
   sire <- sire[sample(1:.N, 100)]
@@ -288,34 +285,41 @@ test_that("survtab_ag allows for certain arguments to be length > 1", {
                pophaz = popmort,
                aggre = list(fot))
   
-  st <- survtab_ag(fot ~ 1, data = x, 
-                   surv.method = "lifetable",
-                   n.cens = c("from0to0", "from0to2"), d = "from0to1")
-  st <- survtab_ag(fot ~ 1, data = x, 
-                   surv.method = "lifetable",
-                   relsurv.method = "pp",
-                   n.cens = c("from0to0", "from0to2"), 
-                   d = "from0to1",
-                   d.pp = "from0to1.pp",
-                   d.pp.2 = "from0to1.pp.2",
-                   n.pp = "at.risk.pp",
-                   n.cens.pp = c("from0to0.pp", "from0to2.pp"))
-  st <- survtab_ag(fot ~ 1, data = x, 
-                   surv.method = "lifetable",
-                   relsurv.method = "pp",
-                   d = c("from0to0", "from0to2"), 
-                   n.cens = "from0to1",
-                   n.cens.pp = "from0to1.pp",
-                   n.pp = "at.risk.pp",
-                   d.pp = c("from0to0.pp", "from0to2.pp"),
-                   d.pp.2 = c("from0to0.pp.2", "from0to2.pp.2"))
+  st1 <- survtab_ag(fot ~ 1, data = x, 
+                    surv.method = "lifetable",
+                    n.cens = c("from0to0", "from0to2"), d = "from0to1")
+  st2 <- survtab_ag(fot ~ 1, data = x, 
+                    surv.method = "lifetable",
+                    relsurv.method = "pp",
+                    n.cens = c("from0to0", "from0to2"), 
+                    d = "from0to1",
+                    d.pp = "from0to1.pp",
+                    d.pp.2 = "from0to1.pp.2",
+                    n.pp = "at.risk.pp",
+                    n.cens.pp = c("from0to0.pp", "from0to2.pp"))
+  st3 <- survtab_ag(fot ~ 1, data = x, 
+                    surv.method = "lifetable",
+                    relsurv.method = "pp",
+                    d = c("from0to0", "from0to2"), 
+                    n.cens = "from0to1",
+                    n.cens.pp = "from0to1.pp",
+                    n.pp = "at.risk.pp",
+                    d.pp = c("from0to0.pp", "from0to2.pp"),
+                    d.pp.2 = c("from0to0.pp.2", "from0to2.pp.2"))
+  
+  testthat::expect_true("surv.obs" %in% names(st1))
+  testthat::expect_true("surv.obs" %in% names(st2))
+  testthat::expect_true("surv.obs" %in% names(st3))
+  testthat::expect_equal(st1[["surv_obs"]], st2[["surv_obs"]])
+  testthat::expect_equal(st2[["surv_obs"]], st3[["surv_obs"]])
+  
 })
 
 
 
 
 
-test_that("update() works with survtab objects", {
+testthat::test_that("update() works with survtab objects", {
   data(sire)
   set.seed(1)
   sire <- sire[sample(1:.N, 100)]
@@ -333,11 +337,11 @@ test_that("update() works with survtab objects", {
   st <- survtab_ag(fot ~ 1, data = x)
   sts <- survtab_ag(fot ~ sex, data = x)
   
-  expect_equal(sts, update(st, formula. = fot ~ sex))
+  testthat::expect_equal(sts, update(st, formula. = fot ~ sex))
   
   
   library(Epi)
-  library(survival)
+  
   x <- Lexis(entry = list(FUT = 0, AGE = dg_age, CAL = get.yrs(dg_date)), 
              exit = list(CAL = get.yrs(ex_date)), 
              data = sire[sire$dg_date < sire$ex_date, ],
@@ -356,7 +360,7 @@ test_that("update() works with survtab objects", {
                  surv.type = "surv.obs",
                  breaks = list(FUT = seq(0, 5, 1/12)))
   
-  expect_equal(sts, update(st, . ~ -group))
+  testthat::expect_equal(sts, update(st, . ~ -group))
   
 })
 
@@ -364,10 +368,10 @@ test_that("update() works with survtab objects", {
 
 
 
-test_that("internal weights work as intended", {
+testthat::test_that("internal weights work as intended", {
   library("data.table")
   data("sire")
-  sire$agegr <- cut(sire$dg_age,c(0,45,55,65,75,Inf),right=F)
+  sire$agegr <- cut(sire$dg_age,c(0,45,55,65,75,Inf),right=FALSE)
   BL <- list(fot=seq(0, 5, by = 1/12),
              per = c("2008-01-01", "2013-01-01"))
   x <- lexpand(sire, birth = bi_date, entry = dg_date, exit = ex_date,
@@ -384,7 +388,7 @@ test_that("internal weights work as intended", {
   
   st2 <- survtab_ag(fot ~ adjust(agegr), data = x, weights = "internal")
   
-  expect_equal(st$surv.obs.as.lo, st2$surv.obs.as.lo)
+  testthat::expect_equal(st$surv.obs.as.lo, st2$surv.obs.as.lo)
   
 })
 
@@ -392,7 +396,7 @@ test_that("internal weights work as intended", {
 
 
 
-test_that("survtab_ag works with bare data.frames", {
+testthat::test_that("survtab_ag works with bare data.frames", {
   
   data(sire)
   
@@ -408,14 +412,14 @@ test_that("survtab_ag works with bare data.frames", {
                          surv.breaks = 0:5))
   
   la <- list(eval(e), eval(eb))
-  expect_equal(la[[1]]$surv.obs.hi, la[[2]]$surv.obs.hi)
+  testthat::expect_equal(la[[1]]$surv.obs.hi, la[[2]]$surv.obs.hi)
   
   
   x <- data.frame(x)
   er <- paste0("Data did not contain breaks and no breaks ",
                "were supplied by hand.")
-  expect_error(eval(e), regexp = er)
-  expect_equal(eval(eb)$surv.obs.hi, la[[2]]$surv.obs.hi)
+  testthat::expect_error(eval(e), regexp = er)
+  testthat::expect_equal(eval(eb)$surv.obs.hi, la[[2]]$surv.obs.hi)
   
 })
 
@@ -424,11 +428,11 @@ test_that("survtab_ag works with bare data.frames", {
 
 
 
-test_that("confidence intervals are as intended", {
-  skip_on_cran()
+testthat::test_that("confidence intervals are as intended", {
+  popEpi:::skip_normally()
   
   library(Epi)
-  library(survival)
+  
 
   ## NOTE: recommended to use factor status variable
   x <- Lexis(entry = list(FUT = 0, AGE = dg_age, CAL = get.yrs(dg_date)),
@@ -453,7 +457,7 @@ test_that("confidence intervals are as intended", {
   dt[, "s.lo" := surv.obs^exp(qnorm(0.995)*SE.A)]
   dt[, "s.hi" := surv.obs^exp(qnorm(0.005)*SE.A)]
   
-  expect_equal(dt[, .(lo = surv.obs.lo, hi = surv.obs.hi)], 
+  testthat::expect_equal(dt[, .(lo = surv.obs.lo, hi = surv.obs.hi)], 
                dt[, .(lo = s.lo, hi = s.hi)])
   
   ## log transformation
@@ -467,7 +471,7 @@ test_that("confidence intervals are as intended", {
   dt[, "s.lo" := surv.obs*exp(qnorm(0.10)*SE.A)]
   dt[, "s.hi" := surv.obs*exp(qnorm(0.90)*SE.A)]
   
-  expect_equal(dt[, .(lo = surv.obs.lo, hi = surv.obs.hi)], 
+  testthat::expect_equal(dt[, .(lo = surv.obs.lo, hi = surv.obs.hi)], 
                dt[, .(lo = s.lo, hi = s.hi)])
   
   
